[Bf-blender-cvs] [57a1e434e5] fracture_modifier: fix for hair particle system, was wrong hair distribution and render error

Martin Felke noreply at git.blender.org
Fri Mar 3 13:20:17 CET 2017


Commit: 57a1e434e50d8937528dad81ad2a6729ff853f81
Author: Martin Felke
Date:   Fri Mar 3 13:19:57 2017 +0100
Branches: fracture_modifier
https://developer.blender.org/rB57a1e434e50d8937528dad81ad2a6729ff853f81

fix for hair particle system, was wrong hair distribution and render error

suppressed "dynamic" particle redistribution for hair now too

===================================================================

M	source/blender/blenkernel/intern/particle_system.c

===================================================================

diff --git a/source/blender/blenkernel/intern/particle_system.c b/source/blender/blenkernel/intern/particle_system.c
index 8e9bd1d701..e4b9700416 100644
--- a/source/blender/blenkernel/intern/particle_system.c
+++ b/source/blender/blenkernel/intern/particle_system.c
@@ -3860,8 +3860,8 @@ static int emit_particles(ParticleSimulationData *sim, PTCacheID *pid, float UNU
 	if (totpart != oldtotpart)
 		realloc_particles(sim, totpart);
 
-	//always allow redistribution of particles, except on grid !
-	if (part->distr == PART_DISTR_GRID) {
+	//always allow redistribution of particles, except on grid and hair systems !
+	if (part->distr == PART_DISTR_GRID || part->type == PART_HAIR) {
 		return totpart - oldtotpart;
 	}




More information about the Bf-blender-cvs mailing list